@@ -1,5 +1,5 @@
 """Base class for commands that need to parse the Runway config."""
-from typing import List, Optional, Union  # pylint: disable=unused-import
+from typing import Any, Dict, Optional  # pylint: disable=unused-import
 import os
 import logging
 
@@ -7,21 +7,34 @@ from ..config import Config, VariablesDefinition  # noqa: F401 pylint: disable=u
 
 
 class BaseCommand(object):
-    """Base class for commands."""
+    """Base class for commands.
+
+    Attributes:
+        DEPRECATION_MSG (str): Template for command deprecation messages.
+        SKIP_FIND_CONFIG (bool): Wether to skip looking for a Runway config file.
+
+    """
 
     DEPRECATION_MSG = ('This command as been deprecated and will be removed '
                        'in the next major release.')
     SKIP_FIND_CONFIG = False  # set to true for commands that don't need config
 
     def __init__(self,
-                 cli_arguments,  # type: List[Union[str, list, bool]]
+                 cli_arguments=None,  # type: Optional[Dict[str, Any]]
                  env_root=None,  # type: Optional[str]
                  runway_config_dir=None  # type: Optional[str]
                  # pylint only complains for python2
                  ):  # pylint: disable=bad-continuation
         # type: (...) -> None
-        """Initialize base class."""
-        self._cli_arguments = cli_arguments
+        """Initialize base class.
+
+        Args:
+            cli_arguments (Optional[Dict[str, Any]]): Args passed from docopt.
+            env_root (Optional[str]): Root directory for the current environment.
+            runway_config_dir (Optional[str]): Path to the Runway config file.
+
+        """
+        self._cli_arguments = cli_arguments or {}
 
         if env_root is None:
             self.env_root = os.getcwd()
@@ -50,7 +63,12 @@ class BaseCommand(object):
     @property
     def runway_config(self):
         # type: () -> Config
-        """Return parsed runway.yml."""
+        """Return parsed runway.yml.
+
+        Returns:
+            runway.config.Config
+
+        """
         if not self._runway_config:
             self._runway_config = Config.load_from_file(
                 self.runway_config_path
@@ -60,11 +78,21 @@ class BaseCommand(object):
     @property
     def runway_vars(self):
         # type: () -> VariablesDefinition
-        """Return parsed Runway variables."""
+        """Return parsed Runway variables.
+
+        Returns:
+            runway.config.VariablesDefinition
+
+        """
         return self.runway_config.variables
 
     def execute(self):
         # type: () -> None
-        """Execute the command."""
+        """Execute the command.
+
+        Raises:
+            NotImplementedError: Method not defined in subclass.
+
+        """
         raise NotImplementedError('execute must be implimented for '
                                   'subclasses of BaseCommand.')
