@@ -1,27 +1,27 @@
 """Runway env module."""
 from __future__ import print_function
 
-# pylint trips up on this in virtualenv
-# https://github.com/PyCQA/pylint/issues/73
-from distutils.util import strtobool  # noqa pylint: disable=no-name-in-module,import-error
-
 import copy
 import logging
 import os
 import sys
-
 from builtins import input
+# pylint trips up on this in virtualenv
+# https://github.com/PyCQA/pylint/issues/73
+from distutils.util import strtobool  # noqa pylint: disable=E
 
 import boto3
 import six
 import yaml
 
-from .runway_command import RunwayCommand, get_env
+# pylint false positive
+from six.moves.collections_abc import Mapping  # pylint: disable=E
+
 from ..context import Context
 from ..path import Path
 from ..runway_module_type import RunwayModuleType
-from ..util import (change_dir, extract_boto_args_from_env, merge_dicts,
-                    merge_nested_environment_dicts)
+from ..util import change_dir, merge_dicts, merge_nested_environment_dicts
+from .runway_command import RunwayCommand, get_env
 
 if sys.version_info[0] > 2:
     import concurrent.futures
@@ -112,8 +112,8 @@ def pre_deploy_assume_role(assume_role_config, context):
         )
 
 
-def select_modules_to_run(deployment, tags, command=None,  # noqa pylint: disable=too-many-branches,invalid-name
-                          ci=False, env_name=None):
+def select_modules_to_run(deployment, tags=None,  # noqa pylint: disable=too-many-branches,invalid-name
+                          command=None, ci=False, env_name=None):
     """Select modules to run based on tags.
 
     Args:
@@ -128,6 +128,7 @@ def select_modules_to_run(deployment, tags, command=None,  # noqa pylint: disabl
         Deployment with filtered modules.
 
     """
+    tags = tags or []
     if ci and not tags:
         return deployment
     modules_to_deploy = []
@@ -180,7 +181,8 @@ def select_modules_to_run(deployment, tags, command=None,  # noqa pylint: disabl
         return deployment
 
     for module in modules:
-        if isinstance(module, str):
+        # checking for string should have been made obsolete by config parser
+        if isinstance(module, str):  # cov: ignore
             LOGGER.warning('Module "%s.%s" is defined as a string '
                            'which cannot be used with the "--tag" '
                            'option so it has been skipped. Please '
@@ -190,7 +192,8 @@ def select_modules_to_run(deployment, tags, command=None,  # noqa pylint: disabl
             continue  # this doesn't need to return an error
         if module.get('child_modules'):
             module['child_modules'] = [x for x in module['child_modules']
-                                       if x.get('tags') and all(i in x['tags'] for i in tags)]
+                                       if x.get('tags') and all(i in x['tags']
+                                                                for i in tags)]
             if module.get('child_modules'):
                 modules_to_deploy.append(module)
         elif module.get('tags') and all(i in module['tags'] for i in tags):
@@ -242,11 +245,6 @@ def validate_account_id(sts_client, account_id):
 
 def validate_account_credentials(deployment, context):
     """Exit if requested deployment account doesn't match credentials."""
-    boto_args = {'region_name': context.env_vars['AWS_DEFAULT_REGION']}
-    for i in ['aws_access_key_id', 'aws_secret_access_key',
-              'aws_session_token']:
-        if context.env_vars.get(i.upper()):
-            boto_args[i] = context.env_vars[i.upper()]
     if isinstance(deployment.get('account_id'), (int, six.string_types)):
         account_id = str(deployment['account_id'])
     elif deployment.get('account_id', {}).get(context.env_name):
@@ -254,7 +252,7 @@ def validate_account_credentials(deployment, context):
     else:
         account_id = None
     if account_id:
-        validate_account_id(boto3.client('sts', **boto_args), account_id)
+        validate_account_id(context.get_session().client('sts'), account_id)
     if isinstance(deployment.get('account_alias'), six.string_types):
         account_alias = deployment['account_alias']
     elif deployment.get('account_alias', {}).get(context.env_name):
@@ -262,56 +260,73 @@ def validate_account_credentials(deployment, context):
     else:
         account_alias = None
     if account_alias:
-        validate_account_alias(boto3.client('iam', **boto_args),
+        validate_account_alias(context.get_session().client('iam'),
                                account_alias)
 
 
-def validate_environment(module_name, env_def, env_vars):
+def validate_environment(context, module, env_def, strict=False):
     """Check if an environment should be deployed to.
 
     Args:
-        module_name (str): Name of the module being validated.
-        env_def (Union[bool, str, List[str]]): Environment definition from
-            the config file. Can be bool, string of "$ACCOUNT_ID/$REGION",
-            or a list of strings.
-        env_vars (Dict[str, str]): Environment variables.
+        context (Context): Runway context object.
+        module (ModuleDefinition): Runway module definition.
+        env_def (Union[bool, Dict[str, Union[bool, str, List[str]]], List[str]]):
+            Environment definition. This should usually be the merged dict of
+            a deployment and module environment definition but will recursively
+            handle nested portions of the definition.
+        strict (bool): Wether to consider the current environment missing from
+            definition as a failure.
 
     Returns:
-        Booleon value of wether to deploy or not.
+        Union[bool, NoneType]: Booleon value of wether to deploy or not.
 
     """
-    if isinstance(env_def, bool):  # explicit enable or disable
-        if env_def:
-            LOGGER.debug('Module \'%s\' explicitly enabled', module_name)
-            return True
+    if isinstance(env_def, bool) or not env_def:
+        if env_def is True:
+            LOGGER.debug('%s: explicitly enabled', module.name)
+        elif env_def is False:
+            LOGGER.info('')
+            LOGGER.info('%s: skipped; explicitly disabled', module.name)
+        else:
+            LOGGER.debug('%s: environment not defined; '
+                         'module will determine deployment', module.name)
+            env_def = None
+        return env_def
+    if isinstance(env_def, dict):
+        if context.env_name not in env_def:
+            if strict:
+                LOGGER.info('%s: skipped; environment not in definition',
+                            module.name)
+                return False
+            LOGGER.info('%s: environment not in definition; '
+                        'module will determine deployment', module.name)
+            return None
+        return validate_environment(context, module,
+                                    env_def.get(context.env_name, False),
+                                    strict)
 
-        LOGGER.info('')
-        LOGGER.info(
-            '---- Skipping module \'%s\'; explicitly disabled ----------',
-            module_name
-        )
+    account_id = context.account_id
+    accepted_values = ['{}/{}'.format(account_id, context.env_region),
+                       account_id, context.env_region, int(account_id)]
+    result = False
+
+    if isinstance(env_def, (int, six.string_types)):
+        LOGGER.debug('%s: checking if "%s" in %s', module.name, env_def,
+                     accepted_values)
+        result = env_def in accepted_values
+    elif isinstance(env_def, list):
+        LOGGER.debug('%s: checking if any(%s in %s)', module.name, env_def,
+                     accepted_values)
+        result = any(val in env_def for val in accepted_values)
+    else:
+        LOGGER.warning('%s: skipped; unsupported type for environments "%s"',
+                       module.name, type(env_def))
         return False
 
-    if isinstance(env_def, (list, six.string_types)):
-        boto_args = extract_boto_args_from_env(env_vars)
-        sts_client = boto3.client('sts', **boto_args)
-        current_env = '{}/{}'.format(
-            sts_client.get_caller_identity()['Account'],
-            env_vars['AWS_DEFAULT_REGION']
-        )
-
-        if current_env in env_def:
-            LOGGER.debug('Current environment \'%s\' found in %s for module \'%s\'',
-                         current_env, str(env_def), module_name)
-            return True
+    if result is False:
         LOGGER.info('')
-        LOGGER.info(
-            '---- Skipping module \'%s\'; account_id/region mismatch ---',
-            module_name
-        )
-        return False
-    raise TypeError('env_def of type "%s" provided to validate_environment; '
-                    'expected type of bool, list, or str' % type(env_def))
+        LOGGER.info('%s: skipped; account_id/region mismatch', module.name)
+    return result
 
 
 class ModulesCommand(RunwayCommand):
@@ -330,10 +345,10 @@ class ModulesCommand(RunwayCommand):
                           command=command)
         context.env_vars['RUNWAYCONFIG'] = self.runway_config_path
 
-        # set default names if needed
-        for i, deployment in enumerate(deployments):
-            if not deployment.get('name'):
-                deployment['name'] = 'deployment_' + str(i + 1)
+        if self.runway_config.future.enabled:
+            LOGGER.info('Future functionality enabled: %s',
+                        ', '.join(self.runway_config.future.enabled))
+            LOGGER.info('')
 
         if command == 'destroy':
             LOGGER.info('WARNING!')
@@ -399,6 +414,7 @@ class ModulesCommand(RunwayCommand):
                 # to the next deployment rather than exiting
                 continue
 
+            # check should be obsolete, checked when the config is parsed
             if deployment.regions or deployment.parallel_regions:
                 if deployment.env_vars:
                     deployment_env_vars = merge_nested_environment_dicts(
@@ -546,21 +562,25 @@ class ModulesCommand(RunwayCommand):
         module_opts['environment'] = module_opts['environments'].get(
             context.env_name, {}
         )
-        if isinstance(module_opts['environment'], dict):  # legacy support
+        if isinstance(module_opts['environment'], dict) and \
+                not self.runway_config.future.strict_environments:
             module_opts['parameters'].update(module_opts['environment'])
             if module_opts['parameters']:
                 # deploy if env is empty but params are provided
                 module_opts['environment'] = True
         else:
-            if not validate_environment(module.name,
-                                        module_opts['environment'],
-                                        context.env_vars):
+            module_opts['environment'] = validate_environment(
+                context=context,
+                module=module,
+                env_def=module_opts['environments'],
+                strict=self.runway_config.future.strict_environments
+            )
+            if module_opts['environment'] is False:  # ignore None
                 return  # skip if env validation fails
-            module_opts['environment'] = True
 
         LOGGER.info("")
         LOGGER.info("---- Processing module '%s' for '%s' in %s --------------",
-                    module.path,
+                    module.name,
                     context.env_name,
                     context.env_region)
         LOGGER.info("Module options: %s", module_opts)
@@ -590,8 +610,7 @@ class ModulesCommand(RunwayCommand):
                 options=module_opts
             )
             if hasattr(module_instance, context.command):
-                command_method = getattr(module_instance, context.command)
-                command_method()
+                module_instance[context.command]()
             else:
                 LOGGER.error("'%s' is missing method '%s'",
                              module_instance, context.command)
@@ -644,10 +663,10 @@ class ModulesCommand(RunwayCommand):
         return [selected_deployment]
 
 
-def _module_name_for_display(module):
+def _module_name_for_display(module):  # this is obsolete
     """Extract a name for the module."""
-    if isinstance(module, dict):
-        return module['path']
+    if isinstance(module, (dict, Mapping)):
+        return module.get('name', module['path'])
     try:
         return module.path
     except Exception:  # pylint: disable=broad-except
@@ -666,6 +685,7 @@ def _module_menu_entry(module, environment_name):
 
 def _deployment_menu_entry(deployment):
     """Build a string to display in the 'select deployment' menu."""
-    paths = ", ".join([_module_name_for_display(module) for module in deployment['modules']])
+    paths = ", ".join([_module_name_for_display(module)
+                       for module in deployment['modules']])
     regions = ", ".join(deployment.get('regions', []))
     return "%s - %s (%s)" % (deployment.get('name'), paths, regions)
