@@ -4,9 +4,12 @@ import logging
 import multiprocessing
 import os
 import sys
+from distutils.util import strtobool  # pylint: disable=E
+
+from six import string_types
 
 from .cfngin.session_cache import get_session
-from .util import AWS_ENV_VARS
+from .util import AWS_ENV_VARS, cached_property
 
 LOGGER = logging.getLogger('runway')
 
@@ -55,6 +58,17 @@ class Context(object):
             self.env_vars.update({'DEPLOY_ENVIRONMENT': self.env_name})
         self.__inject_profile_credentials()  # TODO remove after IaC tools support AWS SSO
 
+    @property
+    def account_id(self):
+        """Get the AccountId of the current AWS account.
+
+        Returns:
+            str: AWS Account ID.
+
+        """
+        client = self.get_session().client('sts')
+        return client.get_caller_identity()['Account']
+
     @property
     def boto3_credentials(self):
         """Return a dict of boto3 credentials."""
@@ -72,6 +86,29 @@ class Context(object):
         return {name: self.env_vars.get(name)
                 for name in AWS_ENV_VARS if self.env_vars.get(name)}
 
+    @cached_property
+    def no_color(self):
+        """Wether to explicitly disable color output.
+
+        Primarily applies to IaC being wrapped by Runway.
+
+        Returns:
+            bool
+
+        """
+        colorize = self.env_vars.get('RUNWAY_COLORIZE')  # explicitly enable/disable
+        try:
+            if isinstance(colorize, bool):  # catch False
+                return not colorize
+            if colorize:
+                if isinstance(colorize, string_types):
+                    return not strtobool(colorize)
+        except ValueError:
+            pass  # likely invalid RUNWAY_COLORIZE value
+        if sys.stdout.isatty():
+            return False
+        return True
+
     @property
     def is_interactive(self):
         """Wether the user should be prompted or not.
