@@ -3,11 +3,16 @@
 import logging
 import os
 
+import boto3
+import pytest
+from botocore.stub import Stubber
 from mock import patch
 
 from runway.context import Context
 from runway.util import environ
 
+from .factories import MockBoto3Session
+
 LOGGER = logging.getLogger('runway')
 
 TEST_CREDENTIALS = {
@@ -20,6 +25,30 @@ TEST_CREDENTIALS = {
 class TestContext(object):
     """Test Context class."""
 
+    def test_account_id(self, monkeypatch):
+        """Test account_id."""
+        account_id = '123456789012'
+        client = boto3.client('sts')
+        stubber = Stubber(client)
+        mock_session = MockBoto3Session(clients={'sts.us-east-1': client},
+                                        region_name='us-east-1')
+        monkeypatch.setattr(Context, 'get_session', lambda self_: mock_session)
+        context = Context(env_name='test',
+                          env_region='us-east-1',
+                          env_root='./',
+                          env_vars={})
+
+        stubber.add_response(method='get_caller_identity',
+                             service_response={'UserId': 'test-user',
+                                               'Account': account_id,
+                                               'Arn': 'arn:aws:iam::{}:'
+                                                      'user/test-user'
+                                                      .format(account_id)})
+
+        with stubber as stub:
+            assert context.account_id == account_id
+        stub.assert_no_pending_responses()
+
     def test_boto3_credentials(self):
         """Test boto3_credentials."""
         context = Context(env_name='test',
@@ -40,6 +69,26 @@ class TestContext(object):
 
         assert context.current_aws_creds == TEST_CREDENTIALS
 
+    @pytest.mark.parametrize('colorize, isatty, expected', [
+        (None, True, False),
+        (None, False, True),
+        (True, False, False),
+        (False, True, True),
+        ('true', False, False),
+        ('false', True, True),
+        (ValueError, True, False),
+        (ValueError, False, True)
+    ])
+    @patch('runway.context.sys.stdout')
+    def test_no_color(self, mock_stdout, colorize, isatty, expected):
+        """Test no_color."""
+        mock_stdout.isatty.return_value = isatty
+        env_vars = {}
+        if colorize is not None:
+            env_vars['RUNWAY_COLORIZE'] = colorize
+        ctx = Context('test', 'us-east-1', './tests', env_vars=env_vars)
+        assert ctx.no_color == expected
+
     def test_is_interactive(self):
         """Test is_interactive."""
         context = Context(env_name='test',
